@@ -16,8 +16,7 @@ You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-from enum import Enum
-from typing import List, Optional, Union
+from typing import Optional
 
 CATEGORIES = (
     "baka",
@@ -40,16 +39,25 @@ CATEGORIES = (
 
 
 class Result:
-    """Represents a response from the API.
-    
+    """Represents an image result from the API.
+
     Attributes
     ----------
-    url: Optional[Union[str, List[str]]]
-        The image(s) url(s).
+    url: Optional[str]
+        The image url.
+    artist_href: Optional[str]
+        The artist's page URL.
+    artist_name: Optional[str]
+        The artist's name.
+    source_url: Optional[str]
+        The original link of this image.
     """
 
     def __init__(self, data: dict):
-        self.url: Optional[Union[str, List[str]]] = data.get("url")
+        self.url: Optional[str] = data.get("url")
+        self.artist_href: Optional[str] = data.get("artist_href")
+        self.artist_name: Optional[str] = data.get("artist_name")
+        self.source_url: Optional[str] = data.get("source_url")
 
     def __repr__(self) -> str:
-        return f"<Result url={self.url}>"
+        return f"<Result url={self.url} artist_href={self.artist_href} artist_name={self.artist_name} source_url={self.source_url}>"
